summary refs log tree commit diff
path: root/crypto/src/openpgp/PgpPrivateKey.cs
diff options
context:
space:
mode:
authorOren Novotny <oren@novotny.org>2015-10-16 20:12:28 -0400
committerOren Novotny <oren@novotny.org>2015-10-16 20:12:28 -0400
commit424bd67b1ab4a909dd6f1d598ad862c30b90c4c6 (patch)
treea0eee2d51cde61950401a6da34c23da8dcc37e76 /crypto/src/openpgp/PgpPrivateKey.cs
parentMerge branch 'master' into master-vs12 (diff)
parentPort of non-blocking TLS API from Java (diff)
downloadBouncyCastle.NET-ed25519-424bd67b1ab4a909dd6f1d598ad862c30b90c4c6.tar.xz
Merge branch 'master' into master-vs12
Diffstat (limited to 'crypto/src/openpgp/PgpPrivateKey.cs')
-rw-r--r--crypto/src/openpgp/PgpPrivateKey.cs37
1 files changed, 23 insertions, 14 deletions
diff --git a/crypto/src/openpgp/PgpPrivateKey.cs b/crypto/src/openpgp/PgpPrivateKey.cs
index 154c87cd7..61487a5b2 100644
--- a/crypto/src/openpgp/PgpPrivateKey.cs
+++ b/crypto/src/openpgp/PgpPrivateKey.cs
@@ -7,33 +7,42 @@ namespace Org.BouncyCastle.Bcpg.OpenPgp
 	/// <remarks>General class to contain a private key for use with other OpenPGP objects.</remarks>
     public class PgpPrivateKey
     {
-        private readonly long keyId;
+        private readonly long keyID;
+        private readonly PublicKeyPacket publicKeyPacket;
         private readonly AsymmetricKeyParameter privateKey;
 
 		/// <summary>
 		/// Create a PgpPrivateKey from a regular private key and the ID of its
 		/// associated public key.
 		/// </summary>
-		/// <param name="privateKey">Private key to use.</param>
-		/// <param name="keyId">ID of the corresponding public key.</param>
-		public PgpPrivateKey(
-            AsymmetricKeyParameter	privateKey,
-            long					keyId)
+		/// <param name="keyID">ID of the corresponding public key.</param>
+        /// <param name="publicKeyPacket">the public key data packet to be associated with this private key.</param>
+        /// <param name="privateKey">the private key data packet to be associated with this private key.</param>
+        public PgpPrivateKey(
+            long                    keyID,
+            PublicKeyPacket         publicKeyPacket,
+            AsymmetricKeyParameter	privateKey)
         {
 			if (!privateKey.IsPrivate)
 				throw new ArgumentException("Expected a private key", "privateKey");
 
-			this.privateKey = privateKey;
-            this.keyId = keyId;
+            this.keyID = keyID;
+            this.publicKeyPacket = publicKeyPacket;
+            this.privateKey = privateKey;
         }
 
-		/// <summary>The keyId associated with the contained private key.</summary>
+        /// <summary>The keyId associated with the contained private key.</summary>
         public long KeyId
         {
-			get { return keyId; }
+			get { return keyID; }
         }
 
-		/// <summary>The contained private key.</summary>
+        /// <summary>The public key packet associated with this private key, if available.</summary>
+        public PublicKeyPacket PublicKeyPacket
+        {
+            get { return publicKeyPacket; }
+        }
+
+        /// <summary>The contained private key.</summary>
         public AsymmetricKeyParameter Key
         {
 			get { return privateKey; }
@@ -7,33 +7,42 @@ namespace Org.BouncyCastle.Bcpg.OpenPgp
         private readonly AsymmetricKeyParameter privateKey;
 
-		/// <summary>
-		/// Create a PgpPrivateKey from a regular private key and the ID of its
-		/// associated public key.
+        /// <summary>
+		/// Create a PgpPrivateKey from a keyID, the associated public data packet, and a regular private key.
 		/// </summary>